# -*- coding: utf-8 -*-
##############################################################################
#
#    cfsa_aftec_formation module for OpenERP, Module de parametrage de formation
#    Copyright (C) 2011 SYLEAM (<http://www.syleam.fr/>)
#              Christophe CHAUVET <christophe.chauvet@syleam.fr>
#
#    This file is a part of cfsa_aftec_formation
#
#    cfsa_aftec_formation is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    cfsa_aftec_formation is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from osv import osv
from osv import fields
from tools.translate import _

class new_user(osv.osv_memory):
    _name = 'wizard.new.user'
    _description = 'Create new user, from template'
    _rec_name = 'nu_name'

    _columns = {
        'nu_name': fields.char('User name', size=64, required=True,),
        'nu_login': fields.char('Login', size=64, required=True,),
        'nu_password': fields.char('Password', size=64, required=True,),
        'nu_template_id': fields.many2one('res.users', 'User template',required=True, help='Select user that must be duplicate'),
        'nu_new_company': fields.boolean('New company', help='Check this, if you want to create a new company, and affect this user on it'),
        'nu_company_name': fields.char('Company Name', size=64, help='Name of the new company'),
        'nu_company_parent_id': fields.many2one('res.company', 'Parent Company', help='Select the parent company for thsi company'),
    }

    def create_data(self, cr, uid, ids, context=None):
        """
        Creation de
        """
        if context is None:
            context = {}

        data_obj = self.pool.get('ir.model.data')
        cmp_id = self.pool.get('res.users').browse(cr, uid, uid, context=context).company_id.id
        print 'user soc: ', cmp_id
        record = self.browse(cr, uid, ids[0], context=context)
        if record.nu_new_company:
            print 'create new company'
            cmp_args = {
                'name': record.nu_company_name,
                'parent_id': record.nu_company_parent_id.id,
                'currency_id': self.pool.get('res.currency').search(cr, uid, [('name', '=', 'EUR')], context=context)[0]
            }
            print cmp_args
            cmp_id = self.pool.get('res.company').create(cr, uid, cmp_args, context=context)
            print 'New company: ', cmp_id

        # Creation de l'utilisateur
        user_args = {
            'name': record.nu_name,
            'login': record.nu_login,
            'password': record.nu_password,
            'company_id': cmp_id,
            'address_id': False,
            'company_ids': [(6, 0, [cmp_id])],
            'signature': _('Please fill your signature in the menu User -> Preference')
        }
        new_user_id = self.pool.get('res.users').copy(cr, uid, record.nu_template_id.id, user_args, context=context)
        print 'New user:', new_user_id

        # Creation des emplacements et entrepôt
        # Creation de l'emplacement racine de type Vue
        location_obj = self.pool.get('stock.location')
        x, loc_phy_id = data_obj.get_object_reference(cr, uid, 'stock', 'stock_location_locations')
        loc_root = data_obj.get_object(cr, uid, 'stock', 'stock_location_company', context=context)
        root_args = {
            'name': record.nu_company_name,
            'usage': 'view',
            'company_id': cmp_id,
            'location_id': loc_phy_id,
            'active': True,
        }
        cur_root_id = location_obj.create(cr, uid, root_args, context=context)
        loc_ids = []
        for l in ('Stock', 'Sortie'):
            loc_args = {
                'name': '%s - %s' % (l, record.nu_company_name),
                'usage': 'internal',
                'company_id': cmp_id,
                'location_id': cur_root_id,
                'active': True,
            }
            loc_ids.append(location_obj.create(cr, uid, loc_args, context=context))

        print 'loc_ids:', loc_ids

        warehouse_args = {
            'name': record.nu_company_name,
            'company_id': cmp_id,
            'lot_input_id': loc_ids[0],
            'lot_stock_id': loc_ids[0],
            'lot_output_id': loc_ids[1],
        }
        warehouse_id = self.pool.get('stock.warehouse').create(cr, uid, warehouse_args, context=context)
        print 'warehouse_id: ', warehouse_id

        # Creation du magasin pour les ventes
        x, sale_shop_id = data_obj.get_object_reference(cr, uid, 'sale', 'shop')
        sale_args = {
            'name': record.nu_company_name,
            'warehouse_id': warehouse_id,
            'company_id': cmp_id,
            'pricelist_id': False,
        }
        shop_id = self.pool.get('sale.shop').copy(cr, uid, sale_shop_id, sale_args, context=context)

        # Creation de toutes les sequences en changeant la société
        seq_obj = self.pool.get('ir.sequence')
        data_seq_ids = data_obj.search(cr, uid, [('model', '=', 'ir.sequence'),('module', 'not in', ('account', 'account_voucher'))], context=context)
        print 'data_seq_ids: ', data_seq_ids
        seq_ids = [x['res_id'] for x in data_obj.read(cr, uid, data_seq_ids, ['res_id'], context=context)]
        print 'seq_ids: ', seq_ids
        for id in seq_ids:
            a = {
                'number_next': 1,
                'company_id': cmp_id,
            }
            seq_obj.copy(cr, uid, id, a, context=context)

        print 'debut compta'
        act_window_ids = self.pool.get('ir.actions.act_window').search(cr, uid,[('name', 'in', ('Accounting Chart Configuration', 'Generate Chart of Accounts from a Chart Template'))], context=context)
        todo_ids = self.pool.get('ir.actions.todo').search(cr, uid, [('action_id', 'in', act_window_ids)], context=context)
        self.pool.get('ir.actions.todo').write(cr, uid, todo_ids, {'state':'open'}, context=context)
        action = self.pool.get('res.config').next(cr, uid, todo_ids[0], context)
        return action

new_user()

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
